from setuptools import setup

setup(name='packeges_test',
      version='0.1',
      description='The funniest joke in the world',
      url='http://github.com/ddi-pc-57/packeges_test',
      author='Flying Circus',
      author_email='packeges_test@example.com',
      license='MIT',
      packages=['packeges_test'],
      zip_safe=False)